@@ -61,6 +61,7 @@ mtypes = [
 ]
 
 text_heatmode = ["Ready", "Ready in Rest", "Rest"]
+text_heatstate = ["Idle", "Heating", "Heat Waiting"]
 text_tscale = ["Farenheit", "Celcius"]
 text_timescale = ["12h", "24h"]
 text_pump = ["Off", "Low", "High"]
@@ -120,6 +121,9 @@ class BalboaSpaWifi:
         self.FILTER_1_2 = 3
         self.OFF = 0
         self.ON = 1
+        self.HEATSTATE_IDLE = 0
+        self.HEATSTATE_HEATING = 1
+        self.HEATSTATE_HEAT_WAITING = 2
 
         # Internal states
         self.host = hostname
@@ -340,20 +344,20 @@ class BalboaSpaWifi:
 
         # calculate how many times to push the button
         if self.pump_array[pump] == 2:
-            for iter in range(0, 2):
+            for iter in range(1, 2+1):
                 if newstate == ((self.pump_status[pump] + iter) % 3):
                     break
         else:
             iter = 1
 
         # now push the button until we hit desired state
-        for pushes in range(0, iter):
+        for pushes in range(1, iter+1):
             # 4 is 0, 5 is 2, presume 6 is 3?
             data[5] = C_PUMP1 + pump
             data[7] = self.balboa_calc_cs(data[1:], 6)
             self.writer.write(data)
             await self.writer.drain()
-            await asyncio.sleep(0.5)
+            await asyncio.sleep(1.0)
 
     async def change_heatmode(self, newmode):
         """ Change the spa's heatmode to newmode. """
@@ -690,7 +694,7 @@ class BalboaSpaWifi:
         self.filter_mode = (data[14] & 0x0c) >> 2
 
         # flag 4 heating, temp range
-        self.heatstate = int(((data[15] & 0x30) >> 4) != 0)
+        self.heatstate = (data[15] & 0x30) >> 4
         self.temprange = (data[15] & 0x04) >> 2
 
         for i in range(0, 6):
@@ -698,9 +702,9 @@ class BalboaSpaWifi:
                 continue
             # 1-4 are in one byte, 5/6 are in another
             if i < 4:
-                self.pump_status[i] = (data[16] >> i) & 0x03
+                self.pump_status[i] = (data[16] >> i*2) & 0x03
             else:
-                self.pump_status[i] = (data[17] >> (i - 4)) & 0x03
+                self.pump_status[i] = (data[17] >> ((i - 4)*2)) & 0x03
 
         if self.circ_pump:
             if data[18] == 0x02:
@@ -774,7 +778,7 @@ class BalboaSpaWifi:
             self.log.error('Message had bad CRC, discarding')
             return None
 
-        # self.log.debug(full_data.hex())
+        # self.log.error('got update: {}'.format(full_data.hex()))
         return full_data
 
     async def check_connection_status(self):
@@ -922,7 +926,7 @@ class BalboaSpaWifi:
     def get_heatstate(self, text=False):
         """ Ask for the current heat state. """
         if text:
-            return text_switch[self.heatstate]
+            return text_heatstate[self.heatstate]
         return self.heatstate
 
     def get_temprange(self, text=False):
